#!/usr/bin/make -f
# -*- mode: makefile; indent-tabs-mode: t -*- vim:noet:ts=4
# Sample Makefile for lexicon generation and installation.

# Little endian platforms: alpha amd64 arm hurd-i386 i386 ia64 mipsel sh3 sh4
# Big endian platforms: hppa m68k mips powerpc ppc64 sparc s390
ifndef ENDIANNESS
	ENDIANNESS = le
endif

SLM_TARGET = lm_sc

SLM2_TEXT_FILE = ${SLM_TARGET}.2gm.arpa
SLM2_FILE = ${SLM_TARGET}.2gm
TSLM2_ORIG_FILE = ${SLM_TARGET}.t2g.orig
TSLM2_DIST_FILE = ${SLM_TARGET}.t2g

SLM3_TEXT_FILE = ${SLM_TARGET}.3gm.arpa
SLM3_FILE = ${SLM_TARGET}.3gm
TSLM3_ORIG_FILE = ${SLM_TARGET}.t3g.orig
TSLM3_DIST_FILE = ${SLM_TARGET}.t3g

DICT_FILE = dict.utf8
PYTRIE_FILE = pydict_sc.bin
PYTRIE_LOG_FILE = pydict_sc.log

SYSTEM_DATA_DIR = ${DESTDIR}/usr/lib/i386-linux-gnu/sunpinyin

all: slm3_dist
install: slm3_install

slm2: ${SLM2_FILE}
${SLM2_FILE}: ${SLM2_TEXT_FILE} ${DICT_FILE}
	slmpack $^ $@

tslm2_orig: ${TSLM2_ORIG_FILE}
${TSLM2_ORIG_FILE}: ${SLM2_FILE}
	slmthread $^ $@

tslm2_dist: ${TSLM2_DIST_FILE}
${TSLM2_DIST_FILE}: ${TSLM2_ORIG_FILE}
	tslmendian -e ${ENDIANNESS} -i $^ -o $@

lexicon2: ${DICT_FILE} ${TSLM2_ORIG_FILE}
	genpyt -e ${ENDIANNESS} -i ${DICT_FILE} -s ${TSLM2_ORIG_FILE} \
		-l ${PYTRIE_LOG_FILE} -o ${PYTRIE_FILE}

slm3: ${SLM3_FILE}
${SLM3_FILE}: ${SLM3_TEXT_FILE} ${DICT_FILE}
	slmpack $^ $@

tslm3_orig: ${TSLM3_ORIG_FILE}
${TSLM3_ORIG_FILE}: ${SLM3_FILE}
	slmthread $^ $@

tslm3_dist: ${TSLM3_DIST_FILE}
${TSLM3_DIST_FILE}: ${TSLM3_ORIG_FILE}
	tslmendian -e ${ENDIANNESS} -i $^ -o $@

lexicon3: ${DICT_FILE} ${TSLM3_ORIG_FILE}
	genpyt -e ${ENDIANNESS} -i ${DICT_FILE} -s ${TSLM3_ORIG_FILE} \
		-l ${PYTRIE_LOG_FILE} -o ${PYTRIE_FILE}

slm2_dist: ${TSLM2_DIST_FILE} lexicon2
slm2_install: ${TSLM2_DIST_FILE} ${PYTRIE_FILE}
	install -d ${SYSTEM_DATA_DIR}
	install -Dm644 $^ ${SYSTEM_DATA_DIR}

slm3_dist: ${TSLM3_DIST_FILE} lexicon3
slm3_install: ${TSLM3_DIST_FILE} ${PYTRIE_FILE}
	install -d ${SYSTEM_DATA_DIR}
	install -Dm644 $^ ${SYSTEM_DATA_DIR}

